# cheatshh

Cheatshh is an interactive CLI meant for managing command line cheatsheets. Now you don't have to remember CLI commands and just refer your cheatsheet. You can group commands and view their TLDR and MAN pages along with a custom description for the command.

# Features

- Comprehensive cheatsheets for various command-line utilities and tools.
- Easy-to-use interface for quickly accessing and executing commands, powered by fuzzy finder(fzf) and whiptail.
- Customizable cheatsheets and groups to suit your needs.
- TLDR and MAN pages visible in the preview.
- Easy to add, edit, delete commands and groups and playing around.
- Press Enter on a command to copy it to clipboard and exit.
- Bookmark your favourite commands and view them in main preview despite being in a group.
- Change configurations like colors, automatic man page display, usages of other cheatsheets like tldr, cheats.sh, etc.

Visit the Github Repository for more details: https://github.com/AnirudhG07/cheatshh

# Version
1.1.1

## Note:
- This package is best used in Unix based systems, like linux and MacOS. For Windows, see the github repository for more details.
- The package is installed in ~/.config/cheatshh directory.

## New Features:
- You can now change various configurations of cheatshh like color_schemes, copy command to use, etc.
- You can change the cheatsheet tool you are using from tldr(default) to cheats.sh, cheatsheet, bropages, etc.
- You can automate the display of man pages for commands.
- You can configure your main preview with group_name/group_command way to find your command really fast.